from .helpers import exec_commands, get_commands, get_config
from .ui import colorized_print, setup_colorama


setup_colorama()


def main() -> None:
    config = get_config("chuy.json")

    for command in get_commands(config):
        try:
            exec_commands(config[command])
        except KeyError:
            colorized_print("  That command is not defined in your configuration!")


if __name__ == "__main__":
    main()



import sys
import typing

from .ui import colorized_print


def keyboard_interrupt(func: typing.Callable) -> typing.Callable:
    """
    This makes the traceback not printed.
    """

    def wrapper(*args, **kwargs):
        try:
            return func(*args, **kwargs)
        except KeyboardInterrupt:
            colorized_print("\n  Process interrupted!")
            sys.exit(0)

    return wrapper



"""
Here I define the methods that help me in the core.
"""
import os
import json
import sys

from .decorators import keyboard_interrupt
from .ui import colorized_print, colorized_input, cyan, magenta, red, yellow


def get_config(configuration_file: str) -> dict:
    """
    Read the config and parse it to a Python dictionary.
    """
    try:
        with open(configuration_file, "r") as reader:
            return json.load(reader)
    except json.decoder.JSONDecodeError:
        colorized_print(" Your configuration is invalid!", red)
        sys.exit(0)
    except FileNotFoundError:
        colorized_print(" I can't find your configuration file :(", red)
        sys.exit(0)


@keyboard_interrupt
def get_commands(config: dict) -> list:
    """
    Get a list with all the commands to execute.
    """

    try:
        return [sys.argv[item] for item in range(1, len(config) - 1)]
    except IndexError:
        list_commands(config)
        return colorized_input("Which command do you want to run? ").split(" ")


@keyboard_interrupt
def list_commands(config: dict) -> None:
    """
    Print all the aliases defined in the config and their respective command.
    """
    colorized_print(" Project Commands:", cyan)

    for item in config:
        colorized_print(
            f"""
  - {item}
      {yellow}$ {magenta}{config[item]}
        """,
            red,
        )


@keyboard_interrupt
def exec_commands(command: str) -> None:
    """
    Print command with colors and then execute it.
    """
    colorized_print(f" $ {command} \n", magenta)
    os.system(command)



"""
Here I define everything related to Colorama :)
"""

import sys

import colorama

# For export, and easily usage :)
cyan, red, yellow, blue, magenta = (
    colorama.Fore.CYAN,
    colorama.Fore.RED,
    colorama.Fore.YELLOW,
    colorama.Fore.BLUE,
    colorama.Fore.MAGENTA,
)


def setup_colorama() -> None:
    """
    Execute init function of Colorama. This is not necessary in Linux or Darwin.
    """
    if "win" in sys.platform:
        colorama.init()


def colorized_input(text: str, color: str = yellow) -> str:
    """
    Same as normal input, but printed with colors.
    """
    return input(f" {color}{text} ")


def colorized_print(
    text: str, color: str = red, brightness: str = colorama.Style.NORMAL, **kwargs
) -> None:
    """
    Print the text with colors.
    """
    print(f"{brightness}{color}{text}{colorama.Style.RESET_ALL}", **kwargs)



"""
This file define chuy as a module.
"""

from .core import main

# Package Data
__version__ = "0.1.1"
__authors__ = ["Eliaz Bobadilla <eliaz.bobadilladev@gmail.com>"]
__author_email__ = "eliaz.bobadilladev@gmail.com"
__url__ = "https://github.com/UltiRequiem/chuy"
__package_name__ = "chuy"



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['chuy']

package_data = \
{'': ['*']}

install_requires = \
['colorama>=0.4.4,<0.5.0']

entry_points = \
{'console_scripts': ['chuy = chuy:main']}

setup_kwargs = {
    'name': 'chuy',
    'version': '1.1.1',
    'description': 'Set alias to long commands and speed up your workflow.',
    'long_description': '# Chuy\n\n![CodeQL](https://github.com/UltiRequiem/chuy/workflows/CodeQL/badge.svg)\n![PyTest](https://github.com/UltiRequiem/chuy/workflows/PyTest/badge.svg)\n![Pylint](https://github.com/UltiRequiem/chuy/workflows/Pylint/badge.svg)\n[![Code Style](https://img.shields.io/badge/Code%20Style-Black-000000.svg)](https://github.com/psf/black)\n[![PyPi Version](https://img.shields.io/pypi/v/chuy)](https://pypi.org/project/chuy)\n![Repo Size](https://img.shields.io/github/repo-size/ultirequiem/chuy?style=flat-square&label=Repo)\n[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)\n![Lines of Code](https://img.shields.io/tokei/lines/github.com/UltiRequiem/chuy?color=blue&label=Total%20Lines)\n\nSet alias to long commands and speed up your workflow,\ninspired in tools like [yarn](https://yarnpkg.com) and [npm](https://github.com/npm/cli).\n\nAlthough Chuy is written in Python, it can be used for projects of any language,\nand even folders that are not projects!\n\n## Install\n\nYou can install [Chuy](https://pypi.org/project/chuy) from PyPI like any other package:\n\n```bash\npip install chuy\n```\n\nTo get the last version:\n\n```bash\npip install git+https:/github.com/UltiRequiem/chuy\n```\n\nIf you use Linux, you may need to install this with sudo to\nbe able to access the command throughout your system.\n\n## Example Configuration file\n\n```json\n{\n  "format": "poetry run black .",\n  "lint": "poetry run pylint chuy tests",\n  "tests": "poetry run pytest",\n  "package": "poetry build && poetry publish"\n}\n```\n\nThis configuration must be in a [`chuy.json`](./chuy.json) file.\nUsually this file goes in the root of your project but it can really go anywhere.\n\n## Usage\n\nAfter having defined the commands in the [chuy.json](./chuy.json) file,\nyou can now execute them as follows:\n\n```bash\nchuy format\n $ poetry run black .\n ....\n```\n\nThis varies depending on the commands you\nhave written in the [chuy file](#example-configuration-file).\n\n```bash\nchuy lint\n $ poetry run pylint chuy tests\n ....\n```\n\nYou can also pass multiple commands:\n\n```bash\nchuy lint format tests\n $ poetry run pylint chuy tests\n ....\n\n $ poetry run black .\n ....\n\n $ poetry run pytest\n ....\n```\n\n### Tricks\n\nIf you do not pass any command, you will get a menu with all the available commands,\nthen you will be asked which of them you want to execute,\nhere you can pass more than one command if you want.\n\n### Screenshots\n\nNormal usage:\n\n![Screenshot Normal Usage](https://i.imgur.com/sOu86gu.png)\n\nAnd if you don\'t pass any command:\n\n![Screenshot Menu](https://i.imgur.com/nFd4Bz9.png)\n\n### License\n\nChuy is licensed under the [MIT License](./LICENSE).\n',
    'author': 'Eliaz Bobadilla',
    'author_email': 'eliaz.bobadilladev@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/UltiRequiem/chuy',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
